<?php

// $Id: MediaExpress.php,v 1.7 2003/05/26 14:24:18 linuxwarrior Exp $
// ----------------------------------------------------------------------
// LICENSE
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License (GPL)
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WIthOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// To read the license please visit http://www.gnu.org/copyleft/gpl.html
// ----------------------------------------------------------------------
// Module: ContentExpress
// Copyright (C) 2002 by the Content Express Development Team.
//                           Arising Group, Inc.
// http://www.widgetbox.net/
// http://xexpress.sourceforge.net/
// Original Author of file: Chester Chee
// Purpose of file:  MediaExpress class
// ----------------------------------------------------------------------

$ModName = basename( dirname( dirname( __FILE__ )));

class MediaExpress
{
    // Called by pntables.php
    function pntables( &$pntable )
    {
        // Get the name for the layout item table.  This is not necessary
        // but helps in the following statements and keeps them readable
        $mediaitems = pnConfigGetVar('prefix') . '_mme_mediaitems';
    
        // Set the table name
        $pntable['mme_mediaitems'] = $mediaitems;
    
        // Set the column names.  Note that the array has been formatted
        // on-screen to be very easy to read by a user.
        $pntable['mme_mediaitems_column'] = array('id'       => $mediaitems . '.mc_id',
                                                  'filename' => $mediaitems . '.mc_filename',
                                                  'filesize' => $mediaitems . '.mc_filesize',
                                                  'mimetype' => $mediaitems . '.mc_type');
    }

    // Called by pninit.php
    function init( $dbconn )
    {
        $pntable = pnDBGetTables();

        // It's good practice to name the table and column definitions you
        // are getting - $table and $column don't cut it in more complex
        // modules
        $mediaitems_table = $pntable['mme_mediaitems'];
        $mediaitems_column = &$pntable['mme_mediaitems_column'];
    
        // Create the table - the formatting here is not mandatory, but it does
        // make the SQL statement relatively easy to read.  Also, separating out
        // the SQL statement from the Execute() command allows for simpler
        // debug operation if it is ever needed
        $sql = "CREATE TABLE $mediaitems_table (
                $mediaitems_column[id] int(11) NOT NULL auto_increment,
                $mediaitems_column[filename] varchar(255) NOT NULL,
                $mediaitems_column[filesize] int(20) NOT NULL,
                $mediaitems_column[mimetype] text NOT NULL,
                PRIMARY KEY (mc_id),
                INDEX(mc_filename),
                UNIQUE(mc_filename));";
    
        $dbconn->Execute($sql);
    
        // Check for an error with the database code, and if so set an
        // appropriate error message and return
        if ($dbconn->ErrorNo() != 0) {
            pnSessionSetVar('errormsg', _CREATETABLEFAILED ." - $mediaitems_table");
            return false;
        }
    
        // Initialize the media mime type
        $sql = "INSERT INTO $mediaitems_table (
                $mediaitems_column[filename],
                $mediaitems_column[filesize],
                $mediaitems_column[mimetype])
                VALUES (
                '',
                0,
                '' );";
    
        $dbconn->Execute($sql);
    
        // Check for an error with the database code, and if so set an
        // appropriate error message and return
        if ($dbconn->ErrorNo() != 0) {
            pnSessionSetVar('errormsg', _CREATETABLEFAILED ." - $mediaitems_table");
            return false;
        }
    
        // Set up an initial value for a module variable.  Note that all module
        // variables should be initialised with some value in this way rather
        // than just left blank, this helps the user-side code and means that
        // there doesn't need to be a check to see if the variable is set in
        // the rest of the code as it always will be
        pnModSetVar('MediaExpress', 'media_types', "application/x-shockwave-flash;application/msword;application/mspowerpoint;application/vnd.ms-project;application/pdf;application/x-pdf;image/jpeg;image/gif;image/pjpeg;image/x-png;image/png" );
        pnModSetVar('MediaExpress', 'max_media_size', 50000 ); // zero - unlimited (not recommended)
        // Default media dimension for display
        pnModSetVar('MediaExpress', 'media_width', 0 );
        pnModSetVar('MediaExpress', 'media_height', 0 );
        // The directory permission of the image repository should set to 755 and owner should be
        // whoever owns the apache server process, most likely - apache
        pnModSetVar('MediaExpress', 'media_repository', "img_repository" );

        return true;
    }

    // Called by pninit.php
    function upgrade($oldversion)
    {
	list($dbconn) = pnDBGetConn();
	$pntable = pnDBGetTables();


	// Update successful
        switch($oldversion) {
            case "1.0":
            case "1.1":
            case "1.1b":
            case "1.1c":
            case "1.1d":
            case "1.2":
            case "1.2.1":

                // Add new table for media to fix the problem is losing MIME type information
                $mediaitems_table = pnConfigGetVar('prefix') . '_ContentExpress_mediaitems';

                // Create the table - the formatting here is not mandatory, but it does
                // make the SQL statement relatively easy to read.  Also, separating out
                // the SQL statement from the Execute() command allows for simpler
                // debug operation if it is ever needed
                $sql = "CREATE TABLE $mediaitems_table (
                        mc_id int(11) NOT NULL auto_increment,
                        mc_filename varchar(255) NOT NULL,
                        mc_filesize int(20) NOT NULL,
                        mc_mimetype text NOT NULL,
                        PRIMARY KEY (mc_id),
                        INDEX(mc_filename),
                        UNIQUE(mc_filename));";

                $dbconn->Execute($sql);

                // Check for an error with the database code, and if so set an
                // appropriate error message and return
                if ($dbconn->ErrorNo() != 0) {
                    pnSessionSetVar('errormsg', _CREATETABLEFAILED ." - $mediaitems_table");
                    return false;
                }

                // Insert the initial mime type for no media content
                $sql = "INSERT INTO $mediaitems_table (
                        mc_filename,
                        mc_filesize,
                        mc_mimetype )
                        VALUES (
                        '',
                        0,
                        '' );";

                $dbconn->Execute($sql);

                // Check for an error with the database code, and if so set an
                // appropriate error message and return
                if ($dbconn->ErrorNo() != 0) {
                    pnSessionSetVar('errormsg', _CREATETABLEFAILED ." - $mediaitems_table");
                    return false;
                }

            case "1.2.2":
            case "1.2.3":
                pnModSetVar('ContentExpress', 'media_types', "application/x-shockwave-flash;application/msword;application/mspowerpoint;application/vnd.ms-project;application/pdf;application/x-pdf;image/jpeg;image/gif;image/pjpeg;image/x-png;image/png" );
            case "1.2.4":
            case "1.2.4.1":
            case "1.2.4.2":
                $old_mediaitems_table = pnConfigGetVar('prefix') . '_ContentExpress_mediaitems';
                $mediaitems_table = $pntable['mme_mediaitems'];

                $sql = "ALTER TABLE $old_mediaitems_table
                        RENAME AS $mediaitems_table";
                $dbconn->Execute($sql);

                // Check for an error with the database code, and if so set an
                // appropriate error message and return
                if ($dbconn->ErrorNo() != 0) {
                    pnSessionSetVar('errormsg', _UPDATETABLEFAILED ." - Rename $old_mediaitems_table to $mediaitems_table");
                    return false;
                }
    
                $media_types = pnModGetVar('ContentExpress', 'media_types');
                pnModSetVar('MediaExpress', 'media_types', $media_types);
                pnModDelVar('ContentExpress', 'media_types');
                $max_media_size = pnModGetVar('ContentExpress', 'max_media_size');
                pnModSetVar('MediaExpress', 'max_media_size', $max_media_size);
                pnModDelVar('ContentExpress', 'max_media_size');
                $media_width = pnModGetVar('ContentExpress', 'media_width');
                pnModSetVar('MediaExpress', 'media_width', $media_width);
                pnModDelVar('ContentExpress', 'media_width');
                $media_height = pnModGetVar('ContentExpress', 'media_height');
                pnModSetVar('MediaExpress', 'media_height', $media_height);
                pnModDelVar('ContentExpress', 'media_height');
                $media_repository = pnModGetVar('ContentExpress', 'media_repository');
                pnModSetVar('MediaExpress', 'media_repository', $media_repository);
                pnModDelVar('ContentExpress', 'media_repository');

            case "1.2.4.3":
            case "1.2.4.4":
            case "1.2.4.5":
            case "1.2.4.6":
            case "1.2.4.7":
            case "1.2.4.8":
            case "1.2.4.9":
            case "1.2.4.10":
            case "1.2.5.1":
            case "1.2.5.2":
            case "1.2.5.3":
            case "1.2.5.4":
                break;
        }
        return true;
    }

    // Called by pninit.php
    function remove()
    {
        // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
        // return arrays but we handle them differently.  For pnDBGetConn()
        // we currently just want the first item, which is the official
        // database handle.  For pnDBGetTables() we want to keep the entire
        // tables array together for easy reference later on
        list($dbconn) = pnDBGetConn();
        $pntable = pnDBGetTables();
    
        // Drop the table - for such a simple command the advantages of separating
        // out the SQL statement from the Execute() command are minimal, but as
        // this has been done elsewhere it makes sense to stick to a single method
        $sql = "DROP TABLE $pntable[mme_mediaitems]";
        $dbconn->Execute($sql);
    
        // Check for an error with the database code, and if so set an
        // appropriate error message and return
        if ($dbconn->ErrorNo() != 0) {
            // Report failed deletion attempt
            pnSessionSetVar('errormsg', _DELETETABLEFAILED ." - $pntable[mme_mediaitems]");
            return false;
        }
    
        // Delete any module variables
        pnModDelVar('MediaExpress', 'media_width' );
        pnModDelVar('MediaExpress', 'media_height' );
        pnModDelVar('MediaExpress', 'media_types' );
        pnModDelVar('MediaExpress', 'max_media_size' );
        pnModDelVar('MediaExpress', 'media_repository' );

        return true;
    }

    // Will be called by pnversion.php
    function version( &$modversion )
    {
        $modversion['name'] = 'MediaExpress';
        $modversion['version'] = '1.2.6.0';
        $modversion['description'] = 'Media Management Module';
        $modversion['credits'] = 'docs/credits.txt';
        $modversion['help'] = 'docs/help.txt';
        $modversion['changelog'] = 'docs/changelog.txt';
        $modversion['license'] = 'docs/license.txt';
        $modversion['official'] = 0;
        $modversion['author'] = 'Chester Chee';
        $modversion['contact'] = 'http://pn.arising.net/ce/';
        $modversion['admin'] = 1;
        $modversion['securityschema'] = array('MediaExpress::' => 'Media ID::');
    }

    // Administrative API helper methods
    // API update media
    function api_updmedia( $args )
    {
        // Get arguments from argument array - all arguments to this function
        // should be obtained from the $args array, getting them from other
        // places such as the environment is not allowed, as that makes
        // assumptions that will not hold in future versions of PostNuke
        extract($args);
    
        // Argument check - make sure that all required arguments are present,
        // if not then set an appropriate error message and return
        if ((!isset($media_url)) || (!isset($upld_media)) ||
            (!isset($upld_media_name)) || (!isset($upld_media_size)) ||
            (!isset($upld_media_type))) {
            pnSessionSetVar('errormsg', _MODARGSERROR);
            return false;
        }
    
        // Get datbase setup - note that both pnDBGetConn() and pnDBGetTables()
        // return arrays but we handle them differently.  For pnDBGetConn()
        // we currently just want the first item, which is the official
        // database handle.  For pnDBGetTables() we want to keep the entire
        // tables array together for easy reference later on
        list($dbconn) = pnDBGetConn();
        $pntable = pnDBGetTables();
    
        // Move the media file to designate directory 
        if( strcmp( $upld_media, "none" ) != 0 && strcmp( $upld_media, "" ) != 0 ) {
    
            // Verify the media file type if appropriate
            $media_types = pnModGetVar( 'MediaExpress', 'media_types' );
            if ( strlen($upld_media_name) > 0 &&
                 strlen($upld_media_type) > 0 &&
                 substr_count($media_types,$upld_media_type) <= 0 ) {
                pnSessionSetVar('errormsg', _MENUCONTENTBADIMGTYPE);
                return false;
            }
    
            // Verify the size of the media file
            $max_media_size = pnModGetVar( 'MediaExpress', 'max_media_size' );
            if( strlen($upld_media_name) > 0 && $max_media_size < $upld_media_size ) {
                pnSessionSetVar('errormsg', _MENUCONTENTIMGTOOBIG);
                return false;
            }
    
            $media_repository = pnModGetVar( 'MediaExpress', 'media_repository' );
            if( is_uploaded_file( $upld_media )) {
                if( !move_uploaded_file( $upld_media, "modules/ContentExpress/".$media_repository."/".$upld_media_name )) {
                    pnSessionSetVar('errormsg', _MENUCONTENTIMGCOPYFAILED);
                    return false;
                }
                // bug fix provided by pini, many thanks!!
                chmod("modules/ContentExpress/$media_repository/$upld_media_name", 0644);

                // It's good practice to name the table and column definitions you
                // are getting - $table and $column don't cut it in more complex
                // modules
                $mediaitems_table = $pntable['mme_mediaitems'];
                $mediaitems_column = &$pntable['mme_mediaitems_column'];
            
                // Add media item - the formatting here is not mandatory, but it does make
                // the SQL statement relatively easy to read.  Also, separating out
                // the sql statement from the Execute() command allows for simpler
                // debug operation if it is ever needed
    
                // Get next ID in table - this is required prior to any insert that
                // uses a unique ID, and ensures that the ID generation is carried
                // out in a database-portable fashion
                $nextId = $dbconn->GenId($mediaitems_table);
        
                $sql = "INSERT INTO $mediaitems_table (
                          $mediaitems_column[id],
                          $mediaitems_column[filename],
                          $mediaitems_column[filesize],
                          $mediaitems_column[mimetype])
                        VALUES (
                          $nextId,
                          '$media_repository/" . pnVarPrepForStore($upld_media_name) . "',
                          " . pnVarPrepForStore($upld_media_size) . ",
                          '" . pnVarPrepForStore($upld_media_type) . "')";
                $dbconn->Execute($sql);
            
                // Check for an error with the database code, and if so set an
                // appropriate error message and return
                if ($dbconn->ErrorNo() != 0) {
                    pnSessionSetVar('errormsg', _MENUCONTENTMEDIADUPLICATE);
                    return false;
                }
            } else {
                pnSessionSetVar('errormsg', _MENUCONTENTMEDIAUPLOADFAILED);
                return false;
            }
        }
    
        // Remove media
        if( $media_url != "" ) {
            // It's good practice to name the table and column definitions you
            // are getting - $table and $column don't cut it in more complex
            // modules
            $contentitems_table = $pntable['ce_contentitems'];
            $contentitems_column = &$pntable['ce_contentitems_column'];
    
            $sql = "SELECT COUNT(*)
                    FROM $contentitems_table
                    WHERE $contentitems_column[media_url] = '". $media_url ."'";
            $result = $dbconn->Execute($sql);
    
    
            // Check for an error with the database code, and if so set an
            // appropriate error message and return
            if ($dbconn->ErrorNo() != 0) {
                pnSessionSetVar('errormsg', _UPDATEFAILED);
                return false;
            }

            if( $result != false ) {
                list( $ref_count ) = $result->fields;
                if( empty( $ref_count ) || $ref_count == 0 ) {
                    if( unlink( "modules/ContentExpress/".$media_url )) {
                        // It's good practice to name the table and column definitions you
                        // are getting - $table and $column don't cut it in more complex
                        // modules
                        $mediaitems_table = $pntable['mme_mediaitems'];
                        $mediaitems_column = &$pntable['mme_mediaitems_column'];
    
                        // Update/Add media item - the formatting here is not mandatory, but it does make
                        // the SQL statement relatively easy to read.  Also, separating out
                        // the sql statement from the Execute() command allows for simpler
                        // debug operation if it is ever needed
                        $sql = "DELETE FROM $mediaitems_table
                                WHERE $mediaitems_column[filename] = '" . $media_url . "'";
                        $dbconn->Execute($sql);

                        // Check for an error with the database code, and if so set an
                        // appropriate error message and return
                        if ($dbconn->ErrorNo() != 0) {
                            pnSessionSetVar('errormsg', _UPDATEFAILED);
                            return false;
                        }
                    }
                } else {
                    pnSessionSetVar('errormsg', _MENUCONTENTIMGINUSE);
                    return false;
                }
            }
        }
    
        // Let the calling process know that we have finished successfully
        return true;
    }

    function admin_mediamanager()
    {
        // Create output object - this object will store all of our output so that
        // we can return it easily when required
        $output = new pnHTML();
    
        // Security check - important to do this as early as possible to avoid
        // potential security holes or just too much wasted processing
    
        if (!pnSecAuthAction(0, 'MediaExpress::', '::', ACCESS_ADMIN)) {
            $output->Text(_MENUCONTENTNOAUTH);
            return $output->GetOutput();
        }
    
        // Add menu to output - it helps if all of the module pages have a standard
        // menu at their head to aid in navigation
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->Text(pnModFunc('ContentExpress', 'admin', 'adminmenu'));
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Title - putting a title ad the head of each page reminds the user what
        // they are doing
        $output->Title(_MENUCONTENTMEDIAMGR);
    
        // Start form - note the use of pnModURL() to create the recipient URL of
        // this form.  All URLs should be generated through pnModURL() to ensure
        // compatibility with future versions of PostNuke
        $output->UploadMode();
        $output->FormStart(pnModURL('ContentExpress', 'admin', 'updatemedia'));
    
    
        // Add an authorisation ID - this adds a hidden field in the form that
        // contains an authorisation ID.  The authorisation ID is very important in
        // preventing certain attacks on the website
        $output->FormHidden('authid', pnSecGenAuthKey());
    
        // Start the table that holds the information to be modified.  Note how
        // each item in the form is kept logically separate in the code; this helps
        // to see which part of the code is responsible for the display of each
        // item, and helps with future modifications
        $output->TableStart();
    
        $media_list = array();
        $media_list[] = array( 'id' => "", 'selected' => 0, 'name' => "" );
        CommonExpress_build_medialist( $media_list );
    
        // Delete media form
        $row = array();
	$output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTMEDIADELETE));
        $row[] = $output->FormSelectMultiple('media_url', $media_list,0,1,$item['media_url'],'','onChange="selectImg(this)"').
        $output->Text(" ").
        $output->Text('<div id="panel"></div>');
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
	$output->SetInputMode(_PNH_VERBATIMINPUT);

        $output->Text( '<script type="text/javascript">'  
		       .'function displayImg(src) {'
                       .'    return \'<img name="myimg" src="\'+src+\'" align="top">\';'
		       .'}'
                       .'function displayFlash(src) {'
                       .'    return \'<OBJECT id="mymovie" CLASSID="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" WIDTH="100" HEIGHT="100" CODEBASE="http://active.macromedia.com/flash5/cabs/swflash.cab#version=5,0,0,0"><PARAM NAME="MOVIE" VALUE="\'+src+\'"><PARAM NAME="PLAY" VALUE="true"><PARAM NAME="LOOP" VALUE="true"><PARAM NAME="QUALITY" VALUE="high"><EMBED id="mymovie" SRC="\'+src+\'" WIDTH="100" HEIGHT="100" PLAY="true" LOOP="true" QUALITY="high" PLUGINSPAGE="http://www.macromedia.com/shockwave/download/index.cgi?P1_Prod_Version=ShockwaveFlash"></EMBED></OBJECT>\';'
 	               .'}'
		       .'  function selectImg(elm) { '
                       .'  var fileStr = elm.value;'
                       .'  var imgelm = document.getElementById("panel");'
                       .'  var fileExt = fileStr.substring(fileStr.length-4, fileStr.length);' 
 		       .'  if ( fileExt.toLowerCase() == ".gif" || fileExt.toLowerCase() == ".jpg" || fileExt.toLowerCase() == ".jpe" || fileExt.toLowerCase() == ".png" || fileStr.substring(fileStr.length-5, fileStr.length).toLowerCase() == ".jpeg") {'
		       .'   imgelm.innerHTML = displayImg( "modules/'.pnModGetName().'/"+elm.value);'
                       .'  } else if (fileExt.toLowerCase() == ".swf"){'
                       .'   imgelm.innerHTML = displayFlash( "modules/'.pnModGetName().'/"+elm.value);'
                       .'  } else {'
       	 	       .'      imgelm.innerHTML = "";'
                       .'  }'
   		       .'} ');

     	$output->Text( '</script>');


        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Upload media form
        $max_media_size = pnModGetVar('MediaExpress', 'max_media_size');
        $row = array();
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTCONTENTIMAGEUPLD));
        $row[] = $output->FormFile('upld_media', 32, $max_media_size );
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // End of upload media form
        $row = array();
        $output->TableRowStart();
        $output->TableColStart( 2, 'left' );
        $output->FormSubmit(_MENUCONTENTUPDATEREPOSITORY);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->SetInputMode(_PNH_PARSEINPUT);
        $output->TableColEnd();
        $output->TableRowEnd();
    
        // End form
        $output->TableEnd();
        $output->FormEnd();
        
        // Return the output that has been generated by this function
        return $output->GetOutput();
    }
    
    function admin_updatemedia( $args )
    {
        // Get parameters from whatever input we need.  All arguments to this
        // function should be obtained from pnVarCleanFromInput(), getting them
        // from other places such as the environment is not allowed, as that makes
        // assumptions that will not hold in future versions of PostNuke
        list( $media_url,
              //$upld_media,
              $upld_media_size,
              $upld_media_name,
              $upld_media_type ) = pnVarCleanFromInput( 'media_url',
                                                        //'upld_media',
                                                        'upld_media_size',
                                                        'upld_media_name',
                                                        'upld_media_type' );
    
        global $upld_media; // Fix for upload image problem on Windows
    
        // User functions of this type can be called by other modules.  If this
        // happens then the calling module will be able to pass in arguments to
        // this function through the $args parameter.  Hence we extract these
        // arguments *after* we have obtained any form-based input through
        // pnVarCleanFromInput().
        extract($args);
    
        // Confirm authorisation code.  This checks that the form had a valid
        // authorisation code attached to it.  If it did not then the function will
        // proceed no further as it is possible that this is an attempt at sending
        // in false data to the system
        if (!pnSecConfirmAuthKey()) {
            pnSessionSetVar('errormsg', _BADAUTHKEY);
            pnRedirect(pnModURL('ContentExpress', 'admin', 'view'));
            return true;
        }
    
        // Fix for the "Bad API argument" due to different version of PHP and Postnuke
        if( is_array( $upld_media )) {
            $upld_media_size = $upld_media['size'];
            $upld_media_type = $upld_media['type'];
            $upld_media_name = $upld_media['name'];
            $upld_media = $upld_media['tmp_name'];
        }

        // Notable by its absence there is no security check here.  This is because
        // the security check is carried out within the API function and as such we
        // do not duplicate the work here
    
        // Load API.  All of the actual work for the update of the new item is done
        // within the API, so we need to load that in before we can do anything.
        // If the API fails to load an appropriate error message is posted and the
        // function returns
        if (!pnModAPILoad('ContentExpress', 'admin')) {
            pnSessionSetVar('errormsg', _LOADFAILED);
            return $output->GetOutput();
        }
    
        // The API function is called.  Note that the name of the API function and
        // the name of this function are identical, this helps a lot when
        // programming more complex modules.  The arguments to the function are
        // passed in as their own arguments array.
        //
        // The return value of the function is checked here, and if the function
        // suceeded then an appropriate message is posted.  Note that if the
        // function did not succeed then the API function should have already
        // posted a failure message so no action is required
        if(pnModAPIFunc('ContentExpress',
                        'admin',
                        'updatemedia',
                        array('media_url' => $media_url,
                              'upld_media_name' => $upld_media_name,
                              'upld_media_size' => $upld_media_size,
                              'upld_media_type' => $upld_media_type,
                              'upld_media' => $upld_media))) {
            // Success
            pnSessionSetVar('statusmsg', _MENUCONTENTMEDIAUPDATED);
        }
    
        // This function generated no output, and so now it is complete we redirect
        // the user to an appropriate page for them to carry on their work
        pnRedirect(pnModURL('ContentExpress', 'admin', 'mediamanager'));
    
        // Return
        return true;
    }

    function admin_modifyconfig()
    {
        // Create output object - this object will store all of our output so that
        // we can return it easily when required
        $output = new pnHTML();
    
        // Security check - important to do this as early as possible to avoid
        // potential security holes or just too much wasted processing
    
        if (!pnSecAuthAction(0, 'MediaExpress::', '::', ACCESS_ADMIN)) {
            $output->Text(_MENUCONTENTNOAUTH);
            return $output->GetOutput();
        }
    
        // Add menu to output - it helps if all of the module pages have a standard
        // menu at their head to aid in navigation
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->Text(pnModFunc('ContentExpress', 'admin', 'adminmenu'));
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Title - putting a title ad the head of each page reminds the user what
        // they are doing
        $output->Title(_MENUCONTENTMODIFYMMECONFIG);
    
        // Start form - note the use of pnModURL() to create the recipient URL of
        // this form.  All URLs should be generated through pnModURL() to ensure
        // compatibility with future versions of PostNuke
        $output->FormStart(pnModURL('ContentExpress', 'admin', 'updatemmeconfig'));
    
    
        // Add an authorisation ID - this adds a hidden field in the form that
        // contains an authorisation ID.  The authorisation ID is very important in
        // preventing certain attacks on the website
        $output->FormHidden('authid', pnSecGenAuthKey());
    
        // Start the table that holds the information to be modified.  Note how
        // each item in the form is kept logically separate in the code; this helps
        // to see which part of the code is responsible for the display of each
        // item, and helps with future modifications
        $output->TableStart( "", "", 0, "100%", 0, 0 );
    
        $media_types = pnModGetVar('MediaExpress', 'media_types');
        $max_media_size = pnModGetVar('MediaExpress', 'max_media_size');
        $media_width = pnModGetVar('MediaExpress', 'media_width');
        $media_height = pnModGetVar('MediaExpress', 'media_height');
        $media_repository = pnModGetVar('MediaExpress', 'media_repository');
     
        // Supported media types
        $row = array();
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTIMAGETYPES));
        $row[] = $output->FormTextArea('media_types', $media_types, 20, 80);
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Max media size
        $row = array();
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTMAXIMGSIZE));
        $row[] = $output->FormText('max_media_size', $max_media_size, 10, 10);
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Default media dimension
        $row = array();
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTCONTENTIMAGEDIM));
        $row[] = $output->FormText('media_width', $media_width, 3, 3).
                 $output->Text( " x " ).
                 $output->FormText('media_height', $media_height, 3, 3).
                 $output->Text( " "._MENUCONTENTCONTENTIMAGEDIMHELP );
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // Media repository
        $row = array();
        $output->SetOutputMode(_PNH_RETURNOUTPUT);
        $row[] = $output->Text(pnVarPrepForDisplay(_MENUCONTENTIMAGEDIR));
        $row[] = $output->FormText('media_repository', $media_repository, 32, 64);
        $output->SetOutputMode(_PNH_KEEPOUTPUT);
        $output->SetInputMode(_PNH_VERBATIMINPUT);
        $output->TableAddrow($row, 'left');
        $output->SetInputMode(_PNH_PARSEINPUT);
    
        // End form
        $output->TableEnd();
        $output->Linebreak(2);
        $output->FormSubmit(_MENUCONTENTUPDATECONFIG);
        $output->FormEnd();
        
        // Return the output that has been generated by this function
        return $output->GetOutput();
    }

    function admin_updateconfig( $args )
    {
        // Get parameters from whatever input we need.  All arguments to this
        // function should be obtained from pnVarCleanFromInput(), getting them
        // from other places such as the environment is not allowed, as that makes
        // assumptions that will not hold in future versions of PostNuke
        $media_types = pnVarCleanFromInput( 'media_types' );
        $media_width = pnVarCleanFromInput( 'media_width' );
        $media_height = pnVarCleanFromInput( 'media_height' );
        $max_media_size = pnVarCleanFromInput( 'max_media_size' );
        $media_repository = pnVarCleanFromInput( 'media_repository' );
    
        extract( $args );
    
        // Confirm authorisation code.  This checks that the form had a valid
        // authorisation code attached to it.  If it did not then the function will
        // proceed no further as it is possible that this is an attempt at sending
        // in false data to the system
        if (!pnSecConfirmAuthKey()) {
            pnSessionSetVar('errormsg', _BADAUTHKEY);
            pnRedirect(pnModURL('ContentExpress', 'admin', 'view'));
            return true;
        }
    
        // Update module variables.  Note that depending on the HTML structure used
        // to obtain the information from the user it is possible that the values
        // might be unset, so it is important to check them all and assign them
        // default values if required
        pnModSetVar('MediaExpress', 'media_types', $media_types);
        pnModSetVar('MediaExpress', 'media_width', $media_width);
        pnModSetVar('MediaExpress', 'media_height', $media_height);
        if( $max_media_size < 0 ) {
            $max_media_size = 50000;
        } else if( $max_media_size > 1000000 ) {
            $max_media_size = 1000000;
        }
        pnModSetVar('MediaExpress', 'max_media_size', $max_media_size);
        if( $media_repository == "" ) {
            $media_repository = "modules/ContentExpress/img_repository";
        }
        pnModSetVar('MediaExpress', 'media_repository', $media_repository);
    
        pnSessionSetVar('statusmsg', _MENUCONTENTCONFIGUPDATED);

        // This function generated no output, and so now it is complete we redirect
        // the user to an appropriate page for them to carry on their work
        pnRedirect(pnModURL('ContentExpress', 'admin', 'view'));
    
        // Return
        return true;
    }
}
?>
